#[repr(C)]pub struct SubFrameworkCommand {
pub cmd: u32,
pub cmdsize: u32,
pub umbrella: u32,
}Expand description
A dynamically linked shared library may be a subframework of an umbrella framework. If so it will be linked with “-umbrella umbrella_name” where Where “umbrella_name” is the name of the umbrella framework. A subframework can only be linked against by its umbrella framework or other subframeworks that are part of the same umbrella framework. Otherwise the static link editor produces an error and states to link against the umbrella framework. The name of the umbrella framework for subframeworks is recorded in the following structure.
Fields
cmd: u32LC_SUB_FRAMEWORK
cmdsize: u32includes umbrella string
umbrella: u32the umbrella framework name