Header

Struct Header 

pub struct Header<'a> {
    pub dos_header: DosHeader,
    pub dos_stub: DosStub<'a>,
    pub rich_header: Option<RichHeader<'a>>,
    pub signature: u32,
    pub coff_header: CoffHeader,
    pub optional_header: Option<OptionalHeader>,
}
The PE header.

Position in a modern PE file

The PE header is located at the very beginning of the file and is followed by the section table and sections.

Fields

dos_header: DosHeaderdos_stub: DosStub<'a>

DOS program for legacy loaders

rich_header: Option<RichHeader<'a>>signature: u32

PE Magic: PE\0\0, little endian

coff_header: CoffHeaderoptional_header: Option<OptionalHeader>

Implementations

Source

impl<'a> Header<'a>

pub fn parse(bytes: &'a [u8]) -> Result<Self>

Parses PE header from the given bytes; this will fail if the DosHeader or DosStub is malformed or missing in some way

pub fn parse_without_dos(bytes: &'a [u8]) -> Result<Self>

Parses PE header from the given bytes, a default DosHeader and DosStub are generated, and any malformed header or stub is ignored