#[repr(C)]pub struct ImageResourceDirectory {
pub characteristics: u32,
pub time_date_stamp: u32,
pub major_version: u16,
pub minor_version: u16,
pub number_of_named_entries: u16,
pub number_of_id_entries: u16,
}Expand description
Represents an image resource directory in the PE (Portable Executable) format.
Fields
characteristics: u32The characteristics of the resource directory.
time_date_stamp: u32The timestamp of when the resource directory was created.
major_version: u16The major version of the resource directory.
minor_version: u16The minor version of the resource directory.
number_of_named_entries: u16The number of named entries in the resource directory.
number_of_id_entries: u16The number of ID entries in the resource directory.
Implementations
Sourceimpl<'a> ImageResourceDirectory
impl<'a> ImageResourceDirectory
pub fn parse( bytes: &'a [u8], dd: DataDirectory, sections: &[SectionTable], file_alignment: u32, ) -> Result<Self>
pub fn parse_with_opts( bytes: &'a [u8], dd: DataDirectory, sections: &[SectionTable], file_alignment: u32, opts: &ParseOptions, ) -> Result<Self>
Sourcepub fn count(&self) -> u16
pub fn count(&self) -> u16
Counts the total number of resource entries (both named and ID entries).
Returns the sum of ImageResourceDirectory::number_of_id_entries and ImageResourceDirectory::number_of_named_entries
from the ImageResourceDirectory.
Sourcepub fn entries_size(&self) -> usize
pub fn entries_size(&self) -> usize
Returns the total size of entries in bytes