#[repr(C)]pub struct VsFixedFileInfo {Show 13 fields
pub signature: u32,
pub struct_version: u32,
pub file_version_ms: u32,
pub file_version_ls: u32,
pub product_version_ms: u32,
pub product_version_ls: u32,
pub file_flags_mask: u32,
pub file_flags: u32,
pub file_os: u32,
pub file_type: u32,
pub file_subtype: u32,
pub file_date_ms: u32,
pub file_date_ls: u32,
}Expand description
Represents the fixed file information structure used in the version resource of a Portable Executable (PE) file.
Fields
signature: u32The signature of the fixed file information structure. Must be equals to VS_FFI_SIGNATURE.
struct_version: u32The version of the structure.
file_version_ms: u32The file version (most significant part).
file_version_ls: u32The file version (least significant part).
product_version_ms: u32The product version (most significant part).
product_version_ls: u32The product version (least significant part).
file_flags_mask: u32The mask for the file flags.
file_flags: u32The file flags that specify characteristics of the file.
file_os: u32The operating system that the file is designed for.
file_type: u32The type of the file (e.g., executable, DLL).
file_subtype: u32The subtype of the file (specific to the file type).
file_date_ms: u32The file date (most significant part).
file_date_ls: u32The file date (least significant part).
Implementations
Sourceimpl VsFixedFileInfo
impl VsFixedFileInfo
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Returns true if Self::signature equals to VS_FFI_SIGNATURE, otherwise false.
Sourcepub fn file_version(&self) -> VersionField
pub fn file_version(&self) -> VersionField
Reinterprets VsFixedFileInfo::file_version_ms and VsFixedFileInfo::file_version_ls into a generic VersionField.
Sourcepub fn product_version(&self) -> VersionField
pub fn product_version(&self) -> VersionField
Reinterprets VsFixedFileInfo::product_version_ms and VsFixedFileInfo::product_version_ls into a generic VersionField.