#[repr(C)]pub struct ExDllCharacteristicsInfo {
pub characteristics_ex: u32,
}Expand description
Represents extended DLL characteristics information.
This structure holds additional characteristics of a DLL that may influence how the operating system loads or manages the DLL, especially in terms of security features and optimizations. These characteristics can include settings related to Intel CET (Control-flow Enforcement Technology) and other security-relevant attributes.
Fields
characteristics_ex: u32The extended characteristics of the DLL.
This field is a bitmask of flags that define various security and performance properties of the DLL. The specific flags are defined by the PE format specification.
This field contains one or more bitflags of:
IMAGE_DLLCHARACTERISTICS_EX_CET_COMPATIMAGE_DLLCHARACTERISTICS_EX_CET_COMPAT_STRICT_MODEIMAGE_DLLCHARACTERISTICS_EX_CET_SET_CONTEXT_IP_VALIDATION_RELAXED_MODEIMAGE_DLLCHARACTERISTICS_EX_CET_DYNAMIC_APIS_ALLOW_IN_PROC_ONLYIMAGE_DLLCHARACTERISTICS_EX_CET_RESERVED_1IMAGE_DLLCHARACTERISTICS_EX_CET_RESERVED_2IMAGE_DLLCHARACTERISTICS_EX_FORWARD_CFI_COMPATIMAGE_DLLCHARACTERISTICS_EX_HOTPATCH_COMPATIBLE
Implementations
Sourceimpl<'a> ExDllCharacteristicsInfo
impl<'a> ExDllCharacteristicsInfo
pub fn parse(bytes: &'a [u8], idd: &ImageDebugDirectory) -> Result<Self>
pub fn parse_with_opts( bytes: &'a [u8], idd: &ImageDebugDirectory, opts: &ParseOptions, ) -> Result<Self>